@@ -33,6 +33,7 @@
 #include "bluetooth-client.h"
 #include "bluetooth-client-private.h"
 #include "bluetooth-chooser.h"
+#include "bluetooth-chooser-private.h"
 #include "gnome-bluetooth-enum-types.h"
 #include "bling-spinner.h"
 
@@ -194,7 +195,7 @@ set_search_label (BluetoothChooser *self, gboolean state)
  * visual feedback that the process is on-going.
  *
  * See also: #BluetoothChooser:show-searching
- */
+ **/
 void
 bluetooth_chooser_start_discovery (BluetoothChooser *self)
 {
@@ -212,7 +213,7 @@ bluetooth_chooser_start_discovery (BluetoothChooser *self)
  * @self: a #BluetoothChooser widget.
  *
  * Stops a discovery started with #bluetooth_chooser_start_discovery.
- */
+ **/
 void
 bluetooth_chooser_stop_discovery (BluetoothChooser *self)
 {
@@ -245,8 +246,7 @@ bluetooth_chooser_get_selected_device_data (BluetoothChooser *self, guint column
  * @self: a #BluetoothChooser widget.
  *
  * Return value: the Bluetooth address for the currently selected device, or %NULL.
- *
- */
+ **/
 gchar *
 bluetooth_chooser_get_selected_device (BluetoothChooser *self)
 {
@@ -258,8 +258,7 @@ bluetooth_chooser_get_selected_device (BluetoothChooser *self)
  * @self: a #BluetoothChooser widget.
  *
  * Return value: the name for the currently selected device, or %NULL.
- *
- */
+ **/
 gchar *
 bluetooth_chooser_get_selected_device_name (BluetoothChooser *self)
 {
@@ -271,8 +270,7 @@ bluetooth_chooser_get_selected_device_name (BluetoothChooser *self)
  * @self: a #BluetoothChooser widget.
  *
  * Return value: the icon name to use to represent the currently selected device, or %NULL.
- *
- */
+ **/
 gchar *
 bluetooth_chooser_get_selected_device_icon (BluetoothChooser *self)
 {
@@ -284,8 +282,7 @@ bluetooth_chooser_get_selected_device_icon (BluetoothChooser *self)
  * @self: a #BluetoothChooser widget.
  *
  * Return value: the #BluetoothType of the device selected, or '0' if unknown.
- *
- */
+ **/
 BluetoothType
 bluetooth_chooser_get_selected_device_type (BluetoothChooser *self)
 {
@@ -308,8 +305,7 @@ bluetooth_chooser_get_selected_device_type (BluetoothChooser *self)
  *
  * Return value: whether the selected device is conncted to this computer,
  * will always be %FALSE if no devices are selected.
- *
- */
+ **/
 gboolean
 bluetooth_chooser_get_selected_device_is_connected (BluetoothChooser *self)
 {
@@ -332,8 +328,7 @@ bluetooth_chooser_get_selected_device_is_connected (BluetoothChooser *self)
  * @value: An empty #GValue to set.
  *
  * Return value: %TRUE if the @value has been set.
- *
- */
+ **/
 gboolean
 bluetooth_chooser_get_selected_device_info (BluetoothChooser *self,
 					    const char *field,
@@ -364,11 +359,40 @@ bluetooth_chooser_get_selected_device_info (BluetoothChooser *self,
 	return TRUE;
 }
 
+/**
+ * bluetooth_chooser_get_model:
+ * @self: A BluetoothChooser widget.
+ *
+ * Return value: The BluetoothChooser's GtkTreeModel.
+ **/
+GtkTreeModel *
+bluetooth_chooser_get_model (BluetoothChooser *self)
+{
+	BluetoothChooserPrivate *priv = BLUETOOTH_CHOOSER_GET_PRIVATE(self);
+	
+	return priv->model;
+}
+
+/**
+ * bluetooth_chooser_get_device_column:
+ * @self: A BluetoothChooser widget.
+ *
+ * Return value: A GtkTreeViewColumn pointer to the device column of the BluetoothChooser.
+ **/
+GtkTreeViewColumn *
+bluetooth_chooser_get_device_column (BluetoothChooser *self)
+{
+	BluetoothChooserPrivate *priv = BLUETOOTH_CHOOSER_GET_PRIVATE(self);
+	
+	return gtk_tree_view_get_column (GTK_TREE_VIEW (priv->treeview), 0);
+}
+
 /**
  * bluetooth_chooser_set_title:
  * @self: a BluetoothChooser widget.
  * @title: the widget header title.
  *
+ * Sets the #BluetoothChooser's title.
  */
 void
 bluetooth_chooser_set_title (BluetoothChooser  *self, const char *title)
@@ -767,6 +791,7 @@ bluetooth_chooser_init(BluetoothChooser *self)
 
 	priv->show_paired = FALSE;
 	priv->show_searching = FALSE;
+	priv->device_type_filter = BLUETOOTH_TYPE_ANY;
 
 	priv->client = bluetooth_client_new ();
 
@@ -1107,13 +1132,11 @@ bluetooth_chooser_class_init (BluetoothChooserClass *klass)
 
 	/**
 	 * BluetoothChooser::selected-device-changed:
-	 *
 	 * @chooser: a #BluetoothChooser widget which received the signal
 	 * @address: the Bluetooth address for the currently selected device, or %NULL
 	 *
 	 * The #BluetoothChooser:selected-device-changed signal is launched when the
 	 * selected device is changed, it will be %NULL if a device was unselected.
-	 *
 	 **/
 	selection_table_signals[SELECTED_DEVICE_CHANGED] =
 		g_signal_new ("selected-device-changed",
@@ -1151,7 +1174,7 @@ bluetooth_chooser_class_init (BluetoothChooserClass *klass)
 		max_filter_val += 1 << i;
 	g_object_class_install_property (G_OBJECT_CLASS(klass),
 					 PROP_DEVICE_TYPE_FILTER, g_param_spec_int ("device-type-filter",
-					 					    "device-type-filter", "A bitmask of #BluetoothType to show", 1, max_filter_val, 1, G_PARAM_READWRITE));
+					 					    "device-type-filter", "A bitmask of #BluetoothType to show", BLUETOOTH_TYPE_ANY, max_filter_val, BLUETOOTH_TYPE_ANY, G_PARAM_READWRITE));
 	g_object_class_install_property (G_OBJECT_CLASS(klass),
 					 PROP_DEVICE_CATEGORY_FILTER, g_param_spec_enum ("device-category-filter",
 											 "device-category-filter", "The #BluetoothCategory to show", BLUETOOTH_TYPE_CATEGORY, BLUETOOTH_CATEGORY_ALL, G_PARAM_READWRITE));
